@@ -178,7 +178,7 @@ class DistributionStatistics(object):
         # Bin the data
         if self.binning_strategy:
             self.binner.fit(d1)
-            d1_preprocessed = self.binner.counts_
+            d1_preprocessed = self.binner.compute(d1)
             d2_preprocessed = self.binner.compute(d2)
         else:
             d1_preprocessed, d2_preprocessed = d1, d2
